@@ -113,7 +113,7 @@ class LaunchProcess(object):
     ) -> None:
         import weakref
         from robotframework_debug_adapter.constants import VALID_TERMINAL_OPTIONS
-        from robotframework_debug_adapter.constants import TERMINAL_NONE
+        from robotframework_debug_adapter.constants import TERMINAL_INTEGRATED
         from robocorp_ls_core.basic import as_str
         import robocorp_ls_core
         from robotframework_debug_adapter.launch_process_robot_target_comm import (
@@ -140,7 +140,7 @@ class LaunchProcess(object):
 
         target = request.arguments.kwargs.get("target")
         self._cwd = request.arguments.kwargs.get("cwd")
-        self._terminal = request.arguments.kwargs.get("terminal", TERMINAL_NONE)
+        self._terminal = request.arguments.kwargs.get("terminal", TERMINAL_INTEGRATED)
         args = request.arguments.kwargs.get("args") or []
         make_suite = request.arguments.kwargs.get("makeSuite", True)
         args = [str(arg) for arg in args]
@@ -432,10 +432,16 @@ class LaunchProcess(object):
             debug_adapter_comm = weak_debug_adapter_comm()
             cmdline = self._cmdline
             if debug_adapter_comm is not None:
+                env = self._env
+                if env:
+                    from robocorp_ls_core import run_with_env
+
+                    cmdline, env = run_with_env.update_cmdline_and_env(cmdline, env)
+
                 debug_adapter_comm.write_to_client_message(
                     RunInTerminalRequest(
                         RunInTerminalRequestArguments(
-                            cwd=self._cwd, args=cmdline, kind=kind, env=self._env
+                            cwd=self._cwd, args=cmdline, kind=kind, env=env
                         )
                     )
                 )
