@@ -250,7 +250,7 @@ def _collect_current_doc_keywords(
     _collect_completions_from_ast(ast, completion_context, collector)
 
 
-_LibInfo = namedtuple("_LibInfo", "name, alias, builtin")
+_LibInfo = namedtuple("_LibInfo", "name, alias, builtin, args")
 
 
 def _collect_libraries_keywords(
@@ -262,23 +262,39 @@ def _collect_libraries_keywords(
     # Get keywords from libraries
     from robotframework_ls.impl.robot_constants import BUILTIN_LIB
     from robocorp_ls_core.lsp import CompletionItemKind
+    from robotframework_ls.impl import ast_utils
 
     libraries = completion_context.get_imported_libraries()
 
-    library_infos = set(
-        _LibInfo(
-            completion_context.token_value_resolving_variables(library.name),
+    # Note: using a dict(_LibInfo:bool) where only the keys are meaningful
+    # because we want to keep the order and sets aren't ordered.
+    library_infos = {}
+    for name, alias, args in (
+        (
+            library.name,
             library.alias,
-            False,
+            ast_utils.get_library_arguments_serialized(library),
         )
         for library in libraries
-    )
-    library_infos.add(_LibInfo(BUILTIN_LIB, None, True))
+    ):
+        if name:
+            lib_info = _LibInfo(
+                completion_context.token_value_resolving_variables(name),
+                alias,
+                False,
+                args,
+            )
+
+            library_infos[lib_info] = True
+
+    library_infos[_LibInfo(BUILTIN_LIB, None, True, None)] = True
     libspec_manager = completion_context.workspace.libspec_manager
 
     for library_info in library_infos:
         completion_context.check_cancelled()
-        if not completion_context.memo.complete_for_library(library_info.name):
+        if not completion_context.memo.complete_for_library(
+            library_info.name, library_info.alias
+        ):
             continue
 
         library_doc = libspec_manager.get_library_info(
@@ -286,6 +302,7 @@ def _collect_libraries_keywords(
             create=True,
             current_doc_uri=completion_context.doc.uri,
             builtin=library_info.builtin,
+            args=library_info.args,
         )
         if library_doc is not None:
             #: :type keyword: KeywordDoc
