@@ -153,6 +153,9 @@ def reader_thread(
                         "message": "Error processing message: %s" % (e,),
                     }
                     write_queue.put(error_msg)
+    except ConnectionError:
+        if get_log_level() > 2:
+            log.exception("ConnectionError (ignored).")
     except:
         log.exception("Error reading message.")
     finally:
@@ -164,7 +167,7 @@ def writer_thread_no_auto_seq(
 ):
     """
     Same as writer_thread but does not set the message 'seq' automatically
-    (meant to be used when responses, which need the seq id set need to be handled). 
+    (meant to be used when responses, which need the seq id set need to be handled).
     """
     try:
         while True:
